.. heka-py documentation master file, created by
   sphinx-quickstart on Wed Feb  8 17:50:44 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst


Contents
========

.. toctree::
   :maxdepth: 5

   getstarted
   config


API Documentation
-----------------

.. toctree::
   :maxdepth: 5

   api/config
   api/client
   api/streams
   api/encoders
   api/filters
   api/decorators
   api/exceptions


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

